@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledco
                 log.debug(LOG_CHECK, "FTP info %s", info)
             else:
                 raise LinkCheckerError(_("Got no answer from FTP server"))
-        except EOFError, msg:
+        except EOFError as msg:
             raise LinkCheckerError(
                       _("Remote host has closed connection: %(msg)s") % str(msg))
 
@@ -103,7 +103,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledco
         See also RFC 2640."""
         try:
             features = self.url_connection.sendcmd("FEAT")
-        except ftplib.error_perm, msg:
+        except ftplib.error_perm as msg:
             log.debug(LOG_CHECK, "Ignoring error when getting FTP features: %s" % msg)
         else:
             log.debug(LOG_CHECK, "FTP features %s", features)
@@ -217,8 +217,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledco
             buf = StringIO()
             def stor_data (s):
                 """Helper method storing given data"""
-                urls = self.aggregate.add_download_data(self.cache_content_key, s)
-                self.warn_duplicate_content(urls)
+                self.aggregate.add_download_data(self.cache_content_key, s)
                 # limit the download size
                 if (buf.tell() + len(s)) > self.MaxFilesizeBytes:
                     raise LinkCheckerError(_("FTP file size too large"))
