@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,8 +52,6 @@ class HttpsUrl (httpurl.HttpUrl):
         cert = ssl_sock.getpeercert()
         log.debug(LOG_CHECK, "Got SSL certificate %s", cert)
         if not cert:
-            msg = _('empty or no certificate found')
-            self.add_ssl_warning(ssl_sock, msg)
             return
         if 'subject' in cert:
             self.check_ssl_hostname(ssl_sock, cert, host)
@@ -118,10 +116,17 @@ class CertificateError(ValueError):
     pass
 
 
-def _dnsname_to_pat(dn):
+def _dnsname_to_pat(dn, max_wildcards=1):
     """Convert a DNS certificate name to a hostname matcher."""
     pats = []
     for frag in dn.split(r'.'):
+        if frag.count('*') > max_wildcards:
+            # Issue #17980: avoid denials of service by refusing more
+            # than one wildcard per fragment.  A survery of established
+            # policy among SSL implementations showed it to be a
+            # reasonable choice.
+            raise CertificateError(
+                "too many wildcards in certificate DNS name: " + repr(dn))
         if frag == '*':
             # When '*' is a fragment by itself, it matches a non-empty dotless
             # fragment.
