@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ from . import (internpaturl, proxysupport, httpheaders as headers, urlbase,
     get_url_from, pooledconnection)
 # import warnings
 from .const import WARN_HTTP_ROBOTS_DENIED, \
-    WARN_HTTP_WRONG_REDIRECT, WARN_HTTP_MOVED_PERMANENT, \
+    WARN_HTTP_MOVED_PERMANENT, \
     WARN_HTTP_EMPTY_CONTENT, WARN_HTTP_COOKIE_STORE_ERROR, \
     WARN_HTTP_DECOMPRESS_ERROR, WARN_HTTP_UNSUPPORTED_ENCODING, \
     WARN_HTTP_AUTH_UNKNOWN, WARN_HTTP_AUTH_UNAUTHORIZED
@@ -166,14 +166,14 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
             self.close_response()
             try:
                 self._try_http_response()
-            except httplib.BadStatusLine, msg:
+            except httplib.BadStatusLine as msg:
                 # some servers send empty HEAD replies
                 if self.method == "HEAD" and self.method_get_allowed:
                     log.debug(LOG_CHECK, "Bad status line %r: falling back to GET", msg)
                     self.fallback_to_get()
                     continue
                 raise
-            except socket.error, msg:
+            except socket.error as msg:
                 # some servers reset the connection on HEAD requests
                 if self.method == "HEAD" and self.method_get_allowed and \
                    msg[0] == errno.ECONNRESET:
@@ -187,14 +187,19 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
             if self.response.status == 305 and self.headers:
                 oldproxy = (self.proxy, self.proxyauth)
                 newproxy = self.getheader("Location")
-                self.add_info(_("Enforced proxy `%(name)s'.") %
-                              {"name": newproxy})
+                if newproxy:
+                    self.add_info(_("Enforced proxy `%(name)s'.") %
+                                  {"name": newproxy})
                 self.set_proxy(newproxy)
                 self.close_response()
-                if not self.proxy:
+                if self.proxy is None:
                     self.set_result(
-                         _("Enforced proxy `%(name)s' ignored, aborting.") %
-                         {"name": newproxy},
+                         _("Missing 'Location' header with enforced proxy status 305, aborting."),
+                         valid=False)
+                    return
+                elif not self.proxy:
+                    self.set_result(
+                         _("Empty 'Location' header value with enforced proxy status 305, aborting."),
                          valid=False)
                     return
                 self._try_http_response()
@@ -202,7 +207,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                 self.proxy, self.proxyauth = oldproxy
             try:
                 tries = self.follow_redirections()
-            except httplib.BadStatusLine, msg:
+            except httplib.BadStatusLine as msg:
                 # some servers send empty HEAD replies
                 if self.method == "HEAD" and self.method_get_allowed:
                     log.debug(LOG_CHECK, "Bad status line %r: falling back to GET", msg)
@@ -269,17 +274,22 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
             # Other sites send 200 with HEAD, but 404 with GET. Bummer.
             poweredby = self.getheader('X-Powered-By', u'')
             server = self.getheader('Server', u'')
+            # Some servers (Zope, Apache Coyote/Tomcat, IIS have wrong
+            # content type with HEAD. This seems to be a common problem.
             if (poweredby.startswith('Zope') or server.startswith('Zope')
+             or server.startswith('Apache-Coyote')
              or ('ASP.NET' in poweredby and 'Microsoft-IIS' in server)):
-                # Zope or IIS server could not get Content-Type with HEAD
-                # http://intermapper.com.dev4.silvertech.net/bogus.aspx
                 return True
         return False
 
     def fallback_to_get(self):
         """Set method to GET and clear aliases."""
+        self.close_response()
+        self.close_connection()
         self.method = "GET"
         self.aliases = []
+        self.urlparts = strformat.url_unicode_split(self.url)
+        self.build_url_parts()
 
     def construct_auth (self):
         """Construct HTTP Basic authentication credentials if there
@@ -430,16 +440,12 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                   redirected, self.recursion_level, self.aggregate,
                   parent_url=self.parent_url, base_ref=self.base_ref,
                   line=self.line, column=self.column, name=self.name)
-            msg = _("Redirection to URL `%(newurl)s' with different scheme"
-                   " found; the original URL was `%(url)s'.") % \
-                 {"url": self.url, "newurl": newobj.url}
             if set_result:
-                self.add_warning(msg, tag=WARN_HTTP_WRONG_REDIRECT)
                 self.set_result(_("syntax OK"))
                 # append new object to queue
                 self.aggregate.urlqueue.put(newobj)
                 return False
-            raise LinkCheckerError(msg)
+            raise LinkCheckerError(_('Cannot redirect to different scheme without result'))
         return True
 
     def check301status (self):
@@ -488,7 +494,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         """
         try:
             self._get_http_response()
-        except socket.error, msg:
+        except socket.error as msg:
             if msg.args[0] == 32 and self.persistent:
                 # server closed persistent connection - retry
                 log.debug(LOG_CHECK, "Server closed connection: retry")
@@ -496,7 +502,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                 self._get_http_response()
             else:
                 raise
-        except httplib.BadStatusLine, msg:
+        except httplib.BadStatusLine as msg:
             if self.persistent:
                 # server closed connection - retry
                 log.debug(LOG_CHECK, "Empty status line: retry")
@@ -637,7 +643,12 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                 h = httplib.HTTPConnection(host, **kwargs)
             elif scheme == "https" and supportHttps:
                 devel_dir = os.path.join(configuration.configdata.install_data, "config")
-                kwargs["ca_certs"] = configuration.get_share_file(devel_dir, 'ca-certificates.crt')
+                sslverify = self.aggregate.config["sslverify"]
+                if sslverify:
+                    if sslverify is not True:
+                        kwargs["ca_certs"] = sslverify
+                    else:
+                        kwargs["ca_certs"] = configuration.get_share_file(devel_dir, 'ca-certificates.crt')
                 h = httplib.HTTPSConnection(host, **kwargs)
             else:
                 msg = _("Unsupported HTTP url scheme `%(scheme)s'") % {"scheme": scheme}
@@ -676,8 +687,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         if len(data) > self.MaxFilesizeBytes:
             raise LinkCheckerError(_("File size too large"))
         dlsize = len(data)
-        urls = self.aggregate.add_download_data(self.cache_content_key, data)
-        self.warn_duplicate_content(urls)
+        self.aggregate.add_download_data(self.cache_content_key, data)
         encoding = headers.get_content_encoding(self.headers)
         if encoding in SUPPORTED_ENCODINGS:
             try:
@@ -685,7 +695,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                     f = StringIO(zlib.decompress(data))
                 else:
                     f = gzip.GzipFile('', 'rb', 9, StringIO(data))
-            except zlib.error, msg:
+            except zlib.error as msg:
                 log.debug(LOG_CHECK, "Error %s data of len %d", encoding, len(data))
                 self.add_warning(_("Decompress error %(err)s") %
                                  {"err": str(msg)},
