@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@ Base URL handler.
 """
 import sys
 import os
-import logging
 import urlparse
 import urllib2
 import urllib
@@ -28,7 +27,7 @@ import errno
 import socket
 import select
 
-from . import absolute_url, StoringHandler, get_url_from
+from . import absolute_url, get_url_from
 from .. import (log, LOG_CHECK, LOG_CACHE, httputil, httplib2 as httplib,
   strformat, LinkCheckerError, url as urlutil, trace, clamav, winutil, geoip,
   fileutil, get_link_pat)
@@ -41,7 +40,7 @@ from .const import (WARN_URL_EFFECTIVE_URL,
     WARN_URL_CONTENT_SIZE_TOO_LARGE, WARN_URL_CONTENT_SIZE_ZERO,
     WARN_URL_CONTENT_SIZE_UNEQUAL, WARN_URL_WHITESPACE,
     WARN_URL_TOO_LONG, URL_MAX_LENGTH, URL_WARN_LENGTH,
-    WARN_URL_CONTENT_DUPLICATE,
+    WARN_SYNTAX_HTML, WARN_SYNTAX_CSS,
     ExcList, ExcSyntaxList, ExcNoCacheList)
 
 # helper alias
@@ -263,7 +262,7 @@ class UrlBase (object):
         try:
             parser.feed(self.get_content())
             parser.flush()
-        except linkparse.StopParse, msg:
+        except linkparse.StopParse as msg:
             log.debug(LOG_CHECK, "Stopped parsing: %s", msg)
         # break cyclic dependencies
         handler.parser = None
@@ -393,7 +392,7 @@ class UrlBase (object):
         try:
             self.build_url()
             self.check_url_warnings()
-        except tuple(ExcSyntaxList), msg:
+        except tuple(ExcSyntaxList) as msg:
             self.set_result(unicode_safe(msg), valid=False)
         else:
             self.set_cache_keys()
@@ -526,14 +525,17 @@ class UrlBase (object):
             self.check_connection()
             self.add_size_info()
             self.add_country_info()
-        except tuple(ExcList):
+        except tuple(ExcList) as exc:
             value = self.handle_exception()
             # make nicer error msg for unknown hosts
-            if isinstance(value, socket.error) and value.args[0] == -2:
+            if isinstance(exc, socket.error) and exc.args[0] == -2:
                 value = _('Hostname not found')
             # make nicer error msg for bad status line
-            if isinstance(value, httplib.BadStatusLine):
+            elif isinstance(exc, httplib.BadStatusLine):
                 value = _('Bad HTTP response %(line)r') % {"line": str(value)}
+            elif isinstance(exc, UnicodeError):
+                # idna.encode(host) failed
+                value = _('Bad hostname %(host)r: %(msg)s') % {'host': self.host, 'msg': str(value)}
             self.set_result(unicode_safe(value), valid=False)
         self.checktime = time.time() - check_start
         if self.do_check_content:
@@ -640,7 +642,7 @@ class UrlBase (object):
         try:
             parser.feed(self.get_content())
             parser.flush()
-        except linkparse.StopParse, msg:
+        except linkparse.StopParse as msg:
             log.debug(LOG_CHECK, "Stopped parsing: %s", msg)
         # break cyclic dependencies
         handler.parser = None
@@ -667,7 +669,7 @@ class UrlBase (object):
         try:
             parser.feed(self.get_content())
             parser.flush()
-        except linkparse.StopParse, msg:
+        except linkparse.StopParse as msg:
             log.debug(LOG_CHECK, "Stopped parsing: %s", msg)
         # break cyclic dependencies
         handler.parser = None
@@ -759,25 +761,9 @@ class UrlBase (object):
         if len(data) > self.MaxFilesizeBytes:
             raise LinkCheckerError(_("File size too large"))
         if not self.is_local():
-            urls = self.aggregate.add_download_data(self.cache_content_key, data)
-            self.warn_duplicate_content(urls)
+            self.aggregate.add_download_data(self.cache_content_key, data)
         return data, len(data)
 
-    def warn_duplicate_content(self, urls):
-        """If given URL list is not empty, warn about duplicate URL content.
-        @param urls: URLs with duplicate content
-        @ptype urls: list of unicode
-        """
-        if not urls or self.size <= 0:
-            return
-        if urlutil.is_duplicate_content_url(self.url, urls[0]):
-            return
-        args = dict(
-            urls=u",".join(urls),
-            size=_(" with %s") % strformat.strsize(self.size),
-        )
-        self.add_warning(_("Content%(size)s is the same as in URLs (%(urls)s).") % args, tag=WARN_URL_CONTENT_DUPLICATE)
-
     def check_content (self):
         """Check content data for warnings, syntax errors, viruses etc."""
         if not (self.valid and self.can_get_content()):
@@ -849,58 +835,6 @@ class UrlBase (object):
                          "size": self.size},
                           tag=WARN_URL_CONTENT_SIZE_UNEQUAL)
 
-    def check_html (self):
-        """Check HTML syntax of this page (which is supposed to be HTML)
-        with the local HTML tidy module."""
-        if not fileutil.has_module("tidy"):
-            return self.check_html_w3()
-        import tidy
-        options = dict(output_html=0, show_warnings=1, quiet=True,
-            input_encoding='utf8', output_encoding='utf8', tidy_mark=0)
-        try:
-            doc = tidy.parseString(self.get_content(), **options)
-            errors = filter_tidy_errors(doc.errors)
-            if errors:
-                for err in errors:
-                    self.add_warning(u"HTMLTidy: %s" % err)
-            else:
-                self.add_info(u"HTMLTidy: %s" % _("valid HTML syntax"))
-        except Exception:
-            # catch _all_ exceptions since we dont want third party module
-            # errors to propagate into this library
-            err = str(sys.exc_info()[1])
-            log.warn(LOG_CHECK,
-                _("tidy HTML parsing caused error: %(msg)s ") %
-                {"msg": err})
-
-    def check_css (self):
-        """Check CSS syntax of this page (which is supposed to be CSS)
-        with the local cssutils module."""
-        if not fileutil.has_module("cssutils"):
-            return self.check_css_w3()
-        import cssutils
-        try:
-            csslog = logging.getLogger('cssutils')
-            csslog.propagate = 0
-            del csslog.handlers[:]
-            handler = StoringHandler()
-            csslog.addHandler(handler)
-            csslog.setLevel(logging.WARN)
-            cssparser = cssutils.CSSParser(log=csslog)
-            cssparser.parseString(self.get_content(), href=self.url)
-            if handler.storage:
-                for record in handler.storage:
-                    self.add_warning(u"cssutils: %s" % record.getMessage())
-            else:
-                self.add_info(u"cssutils: %s" % _("valid CSS syntax"))
-        except Exception:
-            # catch _all_ exceptions since we dont want third party module
-            # errors to propagate into this library
-            err = str(sys.exc_info()[1])
-            log.warn(LOG_CHECK,
-                _("cssutils parsing caused error: %(msg)s") %
-                {"msg": err})
-
     def check_w3_errors (self, xml, w3type):
         """Add warnings for W3C HTML or CSS errors in xml format.
         w3type is either "W3C HTML" or "W3C CSS"."""
@@ -914,26 +848,24 @@ class UrlBase (object):
                 "column": getXmlText(error, "m:col"),
                 "msg": getXmlText(error, "m:message"),
             }
-            self.add_warning(warnmsg % attrs)
+            tag = WARN_SYNTAX_HTML if w3type == "W3C HTML" else WARN_SYNTAX_CSS
+            self.add_warning(warnmsg % attrs, tag=tag)
 
-    def check_html_w3 (self):
+    def check_html (self):
         """Check HTML syntax of this page (which is supposed to be HTML)
         with the online W3C HTML validator documented at
         http://validator.w3.org/docs/api.html
         """
         self.aggregate.check_w3_time()
         try:
-            u = urllib2.urlopen('http://validator.w3.org/check',
-                urllib.urlencode({
-                    'fragment': self.get_content(),
-                    'output': 'soap12',
-                }))
+            body = {'fragment': self.get_content(), 'output': 'soap12'}
+            data = urllib.urlencode(body)
+            u = urllib2.urlopen('http://validator.w3.org/check', data)
             if u.headers.get('x-w3c-validator-status', 'Invalid') == 'Valid':
                 self.add_info(u"W3C Validator: %s" % _("valid HTML syntax"))
                 return
             self.check_w3_errors(u.read(), "W3C HTML")
         except Exception:
-            raise
             # catch _all_ exceptions since we dont want third party module
             # errors to propagate into this library
             err = str(sys.exc_info()[1])
@@ -941,7 +873,7 @@ class UrlBase (object):
                 _("HTML W3C validation caused error: %(msg)s ") %
                 {"msg": err})
 
-    def check_css_w3 (self):
+    def check_css (self):
         """Check CSS syntax of this page (which is supposed to be CSS)
         with the online W3C CSS validator documented at
         http://jigsaw.w3.org/css-validator/manual.html#expert
@@ -1094,6 +1026,8 @@ class UrlBase (object):
             app = winutil.get_word_app()
             try:
                 doc = winutil.open_wordfile(app, filename)
+                if doc is None:
+                    raise winutil.Error("could not open word file %r" % filename)
                 try:
                     for link in doc.Hyperlinks:
                         self.add_url(link.Address, name=link.TextToDisplay)
@@ -1122,11 +1056,11 @@ class UrlBase (object):
             fd.close()
         return filename
 
-    def serialized (self):
+    def serialized (self, sep=os.linesep):
         """
         Return serialized url check data as unicode string.
         """
-        sep = unicode_safe(os.linesep)
+        sep = unicode_safe(sep)
         if self.base_url is not None:
             assert isinstance(self.base_url, unicode), self
         if self.parent_url is not None:
@@ -1191,7 +1125,7 @@ class UrlBase (object):
         @return: URL info
         @rtype: unicode
         """
-        return u"<%s >" % self.serialized()
+        return u"<%s>" % self.serialized(sep=u", ")
 
     def to_wire_dict (self):
         """Return a simplified transport object for logging.
@@ -1263,12 +1197,6 @@ class UrlBase (object):
         return CompactUrlData(self.to_wire_dict())
 
 
-def filter_tidy_errors (errors):
-    """Filter certain errors from HTML tidy run."""
-    return [x for x in errors if not \
-        (x.severity=='W' and x.message=='<table> lacks "summary" attribute')]
-
-
 urlDataAttr = [
     'valid',
     'extern',
