@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,13 +38,13 @@ AppName = configdata.name
 App = AppName+u" "+Version
 Author = configdata.author
 HtmlAuthor = Author.replace(u' ', u'&nbsp;')
-Copyright = u"Copyright (C) 2000-2012 "+Author
-HtmlCopyright = u"Copyright &copy; 2000-2012 "+HtmlAuthor
+Copyright = u"Copyright (C) 2000-2013 "+Author
+HtmlCopyright = u"Copyright &copy; 2000-2013 "+HtmlAuthor
 AppInfo = App+u"              "+Copyright
 HtmlAppInfo = App+u", "+HtmlCopyright
 Url = configdata.url
-SupportUrl = u"http://sourceforge.net/projects/linkchecker/support"
-DonateUrl = u"http://linkchecker.sourceforge.net/donations.html"
+SupportUrl = u"https://github.com/wummel/linkchecker/issues"
+DonateUrl = u"http://wummel.github.io/linkchecker/donations.html"
 Email = configdata.author_email
 UserAgent = u"Mozilla/5.0 (compatible; %s/%s; +%s)" % (AppName, Version, Url)
 Freeware = AppName+u""" comes with ABSOLUTELY NO WARRANTY!
@@ -63,9 +63,7 @@ def normpath (path):
 # List optional Python modules in the form (module, name)
 Modules = (
     ("PyQt4.Qsci", u"QScintilla"),
-    ("optcomplete", u"Optcomplete"),
-    ("tidy", u"HTMLtidy"),
-    ("cssutils", u"CSSutils"),
+    ("argcomplete", u"Argcomplete"),
     ("GeoIP", u"GeoIP"),   # on Unix systems
     ("pygeoip", u"GeoIP"), # on Windows systems
     ("twill", u"Twill"),
@@ -98,7 +96,8 @@ def get_share_file (devel_dir, filename):
     @param filename: filename to search for
     @ptype filename: string
     @return: the found filename or None
-    @rtype: string or None
+    @rtype: string
+    @raises: ValueError if not found
     """
     paths = [
         # when developing
@@ -114,7 +113,8 @@ def get_share_file (devel_dir, filename):
         if os.path.isfile(fullpath):
             return fullpath
     # not found
-    return None
+    msg = "%s not found in %s; check your installation" % (filename, paths)
+    raise ValueError(msg)
 
 
 # dynamic options
@@ -153,63 +153,6 @@ class Configuration (dict):
         self["status"] = False
         self["status_wait_seconds"] = 5
         self["fileoutput"] = []
-        # Logger configurations
-        self["text"] = {
-            "filename": "linkchecker-out.txt",
-            'colorparent':  "default",
-            'colorurl':     "default",
-            'colorname':    "default",
-            'colorreal':    "cyan",
-            'colorbase':    "purple",
-            'colorvalid':   "bold;green",
-            'colorinvalid': "bold;red",
-            'colorinfo':    "default",
-            'colorwarning': "bold;yellow",
-            'colordltime':  "default",
-            'colordlsize':  "default",
-            'colorreset':   "default",
-        }
-        self['html'] = {
-            "filename":        "linkchecker-out.html",
-            'colorbackground': '#fff7e5',
-            'colorurl':        '#dcd5cf',
-            'colorborder':     '#000000',
-            'colorlink':       '#191c83',
-            'colorwarning':    '#e0954e',
-            'colorerror':      '#db4930',
-            'colorok':         '#3ba557',
-        }
-        self['gml'] = {
-            "filename": "linkchecker-out.gml",
-        }
-        self['sql'] = {
-            "filename": "linkchecker-out.sql",
-            'separator': ';',
-            'dbname': 'linksdb',
-        }
-        self['csv'] = {
-            "filename": "linkchecker-out.csv",
-            'separator': ';',
-            "quotechar": '"',
-        }
-        self['blacklist'] = {
-            "filename": "~/.linkchecker/blacklist",
-        }
-        self['xml'] = {
-            "filename": "linkchecker-out.xml",
-        }
-        self['gxml'] = {
-            "filename": "linkchecker-out.gxml",
-        }
-        self['dot'] = {
-            "filename": "linkchecker-out.dot",
-            "encoding": "ascii",
-        }
-        self['sitemap'] = {
-            "filename": "linkchecker-out.sitemap.xml",
-            "encoding": "utf-8",
-        }
-        self['none'] = {}
         self['output'] = 'text'
         self['logger'] = None
         self["warningregex"] = None
@@ -226,11 +169,19 @@ class Configuration (dict):
         self["useragent"] = UserAgent
         self["debugmemory"] = False
         self["localwebroot"] = None
+        self["sslverify"] = True
         self["warnsslcertdaysvalid"] = 14
         self["maxrunseconds"] = None
         self["maxnumurls"] = None
-        from ..logger import Loggers
-        self.loggers = dict(**Loggers)
+        self["maxconnectionshttp"] = 10
+        self["maxconnectionshttps"] = 10
+        self["maxconnectionsftp"] = 2
+        self.loggers = {}
+        from ..logger import LoggerClasses
+        for c in LoggerClasses:
+            key = c.LoggerName
+            self[key] = {}
+            self.loggers[key] = c
 
     def init_logging (self, status_logger, debug=None, handler=None):
         """
@@ -283,23 +234,16 @@ class Configuration (dict):
         for key in loggers:
             logging.getLogger(lognames[key]).setLevel(level)
 
-    def logger_new (self, loggertype, **kwargs):
-        """
-        Instantiate new logger and return it.
-        """
-        args = {}
-        args.update(self[loggertype])
+    def logger_new (self, loggername, **kwargs):
+        """Instantiate new logger and return it."""
+        args = self[loggername]
         args.update(kwargs)
-        return self.loggers[loggertype](**args)
+        return self.loggers[loggername](**args)
 
-    def logger_add (self, loggertype, loggerclass, loggerargs=None):
-        """
-        Add a new logger type to the known loggers.
-        """
-        if loggerargs is None:
-            loggerargs = {}
-        self.loggers[loggertype] = loggerclass
-        self[loggertype] = loggerargs
+    def logger_add (self, loggerclass):
+        """Add a new logger type to the known loggers."""
+        self.loggers[loggerclass.LoggerName] = loggerclass
+        self[loggerclass.LoggerName] = {}
 
     def read (self, files=None):
         """
@@ -352,6 +296,10 @@ class Configuration (dict):
                 return (auth['user'], auth['password'])
         return (None, None)
 
+    def get_connectionlimits(self):
+        """Get dict with limit per connection type."""
+        return {key: self['maxconnections%s' % key] for key in ('http', 'https', 'ftp')}
+
     def sanitize (self):
         "Make sure the configuration is consistent."
         if self["anchors"]:
@@ -473,7 +421,7 @@ def get_user_config():
                     userdir += "."
                 os.mkdir(userdir, 0700)
             shutil.copy(initialconf, userconf)
-        except StandardError, errmsg:
+        except StandardError as errmsg:
             msg = _("could not copy initial configuration file %(src)r to %(dst)r: %(errmsg)r")
             args = dict(src=initialconf, dst=userconf, errmsg=errmsg)
             log.warn(LOG_CHECK, msg % args)
@@ -495,7 +443,7 @@ def get_gconf_http_proxy ():
                 if not port:
                     port = 8080
                 return "%s:%d" % (host, port)
-    except StandardError, msg:
+    except StandardError as msg:
         log.debug(LOG_CHECK, "error getting HTTP proxy from gconf: %s", msg)
     return None
 
@@ -514,7 +462,7 @@ def get_gconf_ftp_proxy ():
             if not port:
                 port = 8080
             return "%s:%d" % (host, port)
-    except StandardError, msg:
+    except StandardError as msg:
         log.debug(LOG_CHECK, "error getting FTP proxy from gconf: %s", msg)
     return None
 
@@ -528,7 +476,7 @@ def get_kde_http_proxy ():
     try:
         data = read_kioslaverc(config_dir)
         return data.get("http_proxy")
-    except StandardError, msg:
+    except StandardError as msg:
         log.debug(LOG_CHECK, "error getting HTTP proxy from KDE: %s", msg)
 
 
@@ -541,7 +489,7 @@ def get_kde_ftp_proxy ():
     try:
         data = read_kioslaverc(config_dir)
         return data.get("ftp_proxy")
-    except StandardError, msg:
+    except StandardError as msg:
         log.debug(LOG_CHECK, "error getting FTP proxy from KDE: %s", msg)
 
 # The following KDE functions are largely ported and ajusted from
