@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2012 Bastian Kleineidam
+# Copyright (C) 2000-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             self.read_checking_config()
             self.read_authentication_config()
             self.read_filtering_config()
-        except Exception, msg:
+        except Exception as msg:
             raise LinkCheckerError(
               _("Error parsing configuration: %s") % unicode(msg))
 
@@ -91,8 +91,9 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
     def read_output_config (self):
         """Read configuration options in section "output"."""
         section = "output"
-        from ..logger import Loggers
-        for key in Loggers.iterkeys():
+        from ..logger import LoggerClasses
+        for c in LoggerClasses:
+            key = c.LoggerName
             if self.has_section(key):
                 for opt in self.options(key):
                     self.config[key][opt] = self.get(key, opt)
@@ -127,7 +128,8 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
             # strip names from whitespace
             loggers = (x.strip().lower() for x in loggers)
             # no file output for the blacklist and none Logger
-            loggers = (x for x in loggers if x in Loggers and
+            from ..logger import LoggerNames
+            loggers = (x for x in loggers if x in LoggerNames and
                        x not in ("blacklist", "none"))
             for val in loggers:
                 output = self.config.logger_new(val, fileoutput=1)
@@ -149,6 +151,8 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
         self.read_string_option(section, "nntpserver")
         self.read_string_option(section, "useragent")
         self.read_int_option(section, "pause", key="wait", min=0)
+        for name in ("http", "https", "ftp"):
+            self.read_int_option(section, "maxconnections%s" % name, min=1)
         self.read_check_options(section)
 
     def read_check_options (self, section):
@@ -163,6 +167,10 @@ class LCConfigParser (ConfigParser.RawConfigParser, object):
                 self.getboolean(section, "cookies")
         self.read_string_option(section, "cookiefile")
         self.read_string_option(section, "localwebroot")
+        try:
+            self.read_boolean_option(section, "sslverify")
+        except ValueError:
+            self.read_string_option(section, "sslverify")
         self.read_int_option(section, "warnsslcertdaysvalid", min=1)
         self.read_int_option(section, "maxrunseconds", min=0)
 
