@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2005-2012 Bastian Kleineidam
+# Copyright (C) 2005-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ import stat
 import fnmatch
 import mimetypes
 import tempfile
+import importlib
 from distutils.spawn import find_executable
 
 from .decorators import memoized
@@ -59,17 +60,20 @@ def write_file (filename, content, backup=False, callback=None):
         os.remove(filename+".bak")
 
 
-def has_module (name):
+def has_module (name, without_error=True):
     """Test if given module can be imported.
+    @param without_error: True if module must not throw any errors when importing
     @return: flag if import is successful
     @rtype: bool
     """
     try:
-        exec "import %s" % name
+        importlib.import_module(name)
         return True
-    except (OSError, ImportError):
-        # some modules (for example HTMLtidy) raise OSError
+    except ImportError:
         return False
+    except Exception:
+        # some modules raise errors when intitializing
+        return not without_error
 
 
 class GlobDirectoryWalker (object):
@@ -137,16 +141,10 @@ class Buffer (object):
         return data
 
 
-@memoized
-def get_stat(filename):
-    """Return stat(2) data for given filename. Kan raise os.error"""
-    return os.stat(filename)
-
-
 def get_mtime (filename):
     """Return modification time of filename or zero on errors."""
     try:
-        return get_stat(filename)[stat.ST_MTIME]
+        return os.path.getmtime(filename)
     except os.error:
         return 0
 
@@ -154,7 +152,7 @@ def get_mtime (filename):
 def get_size (filename):
     """Return file size in Bytes, or -1 on error."""
     try:
-        return get_stat(filename)[stat.ST_SIZE]
+        return os.path.getsize(filename)
     except os.error:
         return -1
 
@@ -196,7 +194,7 @@ def init_mimedb():
     global mimedb
     try:
         mimedb = mimetypes.MimeTypes(strict=False)
-    except StandardError, msg:
+    except StandardError as msg:
         log.error(LOG_CHECK, "could not initialize MIME database: %s" % msg)
         return
     # For Opera bookmark files (opera6.adr)
@@ -273,7 +271,7 @@ def is_readable(filename):
 
 def is_accessable_by_others(filename):
     """Check if file is group or world accessable."""
-    mode = get_stat(filename)[stat.ST_MODE]
+    mode = os.stat(filename)[stat.ST_MODE]
     return mode & (stat.S_IRWXG | stat.S_IRWXO)
 
 
