@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2012 Bastian Kleineidam
+# Copyright (C) 2004-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -63,7 +63,6 @@ class TestHttpRedirect (HttpServerTest):
             u"real url %s" % rurl,
             u"name Recursive Redirect",
             u"info 1 URL parsed.",
-            u"warning Content with 45B is the same as in URLs (%s)." % nurl,
             u"valid",
         ]
         self.direct(url, resultlines, recursionlevel=99)
@@ -82,7 +81,6 @@ class TestHttpRedirect (HttpServerTest):
             u"cache key %s" % nurl,
             u"real url %s" % nurl,
             u"info Redirected to `%s'." % rurl,
-            u"warning Redirection to URL `%s' with different scheme found; the original URL was `%s'." % (rurl, nurl),
             u"valid",
             u"url %s" % rurl,
             u"cache key %s" % rurl,
